@@ -325,13 +325,19 @@ class GraphButton(Button):
 
         values = self.update(graph_size[0] - 2)
         print(f"### RENDERING {self.label!r} ===================")
-        print(f"### GRAPH ASK FOR {graph_size[0] - 2}, GOT {len(values)}")
+        print(f"### GRAPH ASK FOR {graph_size[0] - 2} DATA POINTS")
         min_val = 9999
         max_val = -9999
+        print(f"### LOOPING OVER {len(values)} TRACES")
         for entry in values:
+            print(f"### ENTRY {entry}")
             data = entry["data"]
-            min_val = entry.get("min", min(min_val, min(data)))
-            max_val = entry.get("min", max(max_val, max(data)))
+            if len(data) > 0:
+                min_val = entry.get("min", min(min_val, min(data)))
+                max_val = entry.get("min", max(max_val, max(data)))
+            else:
+                min_val = 0
+                max_val = 0
         print(f"### MIN {min_val}, MAX {max_val}")
 
         range = max_val - min_val
